![architecture](images/logo-s.png)  

Suite of mycology applications and tools for automating common lab workflows.

- Website: https://mycolab.org
- Email: <info@mycolab.org>
- Github: https://github.com/mycolab
- Discord: https://discord.gg/STW6wXaNBC

## Features
- Add specimens
- Search GenBank
- Curate [FASTA](https://en.wikipedia.org/wiki/FASTA_format) files
- Align sequences
- Generate phylogenetic trees
- Publish findings to various sites: 
  - [Genbank](https://blast.ncbi.nlm.nih.gov)
  - [iNaturalist](https://inaturalist.org)
  - [MushroomObserver](https://mushroomobserver.org)

## Architecture
![architecture](images/architecture.png)